import time
import uuid
from math import trunc
from datetime import datetime
from podeli.BnplApi import *
from podeli.model.BnplOrderItem import BnplOrderItem
from podeli.model.RefundOrderRequest import RefundInfo, RefundItem


def get_random_order_id():
    # берем количество секунд с начала времен
    return trunc((datetime.now() - datetime(1, 1, 1)).total_seconds())


def create_commit_refund_example(api: BnplApi, x_correlation_id: str, order: BnplOrder, client: BnplClientInfo):
    try:
        print("Запрашиваем создание заказа")
        result = api.create_order(
            order=order,
            client=client,
            x_correlation_id=x_correlation_id,
            success_url="http://podeli.ru/success_url",
            fail_url="http://podeli.ru/fail_url",
            notification_url="http://podeli.ru/notification_url"
        )
        print(result)

        # пауза для обновления информации в сервисе
        time.sleep(1)

        print("запрашиваем информацию о состоянии закза")
        info_result = api.get_order_info(order_id=order.id, x_correlation_id=x_correlation_id)
        print(info_result)

        print("подтверждаем заказ")
        commit_result = api.commit_order(order=order, x_correlation_id=x_correlation_id)
        print(commit_result)

        # пауза для обновления информации в сервисе
        time.sleep(1)

        print("запрашиваем информацию о состоянии закза")
        info_result = api.get_order_info(order_id=order.id, x_correlation_id=x_correlation_id)
        print(info_result)

        print("запрашиваем возврат одной штуки одной позиции")
        refund_item = RefundItem(item_id=333, refunded_quantity=1,
                                 refunded_sum=25, description='description')
        refund_info = RefundInfo(refund_id=3334444, initiator='shop', items=[refund_item])
        refund_result = api.refund_order(
            order_id=order.id,
            x_correlation_id=x_correlation_id,
            refund_info=refund_info)
        print(refund_result)

        info_result = api.get_order_info(order_id=order.id, x_correlation_id=x_correlation_id)
        print(info_result)

    except BnlpStatusError as e:
        print(e)
    except Exception as e:
        print(e)


def create_cancel_example(api: BnplApi, x_correlation_id: str, order: BnplOrder, client: BnplClientInfo):
    try:
        print("Запрашиваем создание заказа")
        result = api.create_order(
            order=order,
            client=client,
            x_correlation_id=x_correlation_id,
            success_url="http://podeli.ru/success_url",
            fail_url="http://podeli.ru/fail_url",
            notification_url="http://podeli.ru/notification_url"
        )
        print(result)

        # пауза для обновления информации в сервисе
        time.sleep(1)

        print("запрашиваем информацию о состоянии закза")
        info_result = api.get_order_info(order_id=order.id, x_correlation_id=x_correlation_id)
        print(info_result)

        print("запрашиваем отмену заказа")
        result = api.cancel_order(order_id=order.id, x_correlation_id=x_correlation_id, initiator='client')
        print(result)

        # пауза для обновления информации в сервисе
        time.sleep(1)

        print("запрашиваем информацию о состоянии закза")
        info_result = api.get_order_info(order_id=order.id, x_correlation_id=x_correlation_id)
        print(info_result)

        print("пытаемся подтвердить отмененный заказ")
        # пауза для обновления информации в сервисе
        time.sleep(1)
        try:
            commit_result = api.commit_order(order=order, x_correlation_id=x_correlation_id)
            print("сюда мы не попадем, т.к. будет ошибка подтверждения отмененного заказа")
            print(commit_result)
        except BnlpStatusError as e:
            print(f"Получили ошибку потдверждения отмененного заказа\n{e}")

    except BnlpStatusError as e:
        print(f"Ошибка API {e}")
    except Exception as e:
        print(f"Неизвестная ошибка {e}")


def main():
    api = BnplApi(
        login='test',
        password='test',
        cert_file='example/client.pem',
        cert_key='example/client.key',
        url='https://api-dev.podeli.ru/partners',
        proxy=None,
        verify_ssl=False
    )
    client = BnplClientInfo(
        first_name="Андрей",
        last_name="Андрейко",
        middle_name="Андреевич",
        birthdate="1985-01-01",
        phone="79225450799",
        email="andreyko@mail.ru")

    order_item = BnplOrderItem(
        item_id=333,
        article="article",
        name="name",
        amount=50,
        quantity=2,
        prepaid_amount=25
    )

    order = BnplOrder(
        order_id=get_random_order_id(),
        amount=100,
        prepaid_amount=50,
        items=[order_item]
    )

    print("========== Создание-подтверждение-возврат заказа =========")
    x_correlation_id = str(uuid.uuid4())
    create_commit_refund_example(api=api, x_correlation_id=x_correlation_id, order=order, client=client)

    print("======== Создание-удаление заказа =========")
    # для теста создаем новый уникальный идентификатор заказа
    order.id = get_random_order_id()
    # и новый уникальный x_correlation_id
    x_correlation_id = str(uuid.uuid4())
    create_cancel_example(api=api, x_correlation_id=x_correlation_id, order=order, client=client)


if __name__ == '__main__':
    main()
