from podeli.error import BnlpFormatError


class BnplClientInfo:
    """
    Хранит информацию о клиенте

    Используется для передачи информации о клиенте
    """
    def __init__(self,
                 first_name: str,
                 middle_name: str,
                 last_name: str,
                 birthdate: str,
                 phone: str,
                 email: str
                 ):
        """
        Создание информации о клиенте
        :param first_name: Имя
        :param middle_name: Отчество
        :param last_name: Фамилия
        :param birthdate: дата рождения
        :param phone: телефон
        :param email: электронная почта
        """
        self.firstName = first_name
        self.middleName = middle_name
        self.lastName = last_name
        self.birthdate = birthdate
        self.phone = phone
        self.email = email

    @classmethod
    def from_dict(cls, data: dict):
        """
        создает информацию о клиенте с параметрами из словаря
        :param data: данные клиента в dict
        :return: данные о клиенте типа BnplClientInfo
        :rtype: BnplClientInfo
        """
        try:
            return cls(data["firstName"],
                       data["middleName"],
                       data["lastName"],
                       data["birthdate"],
                       data["phone"],
                       data["email"])
        except KeyError as e:
            raise BnlpFormatError(message=e)

    def __str__(self):
        return f"Name={self.firstName}_{self.middleName}_{self.lastName} " \
               f"Birth={self.birthdate} Phone={self.phone} email={self.email}"

    def to_dict(self):
        """
        преобразует данные клиента в dict
        :return: dict
        :rtype: dict
        """
        return self.__dict__
