import requests

from podeli.error import BnlpFormatError
from podeli.model.InfoOrderResponse import PaymentInfo


class CancelOrderResponse:
    """
    Ответ на запрос отмены заказа

    Используется для получения ответа об отмене заказа
    """

    def __init__(
            self,
            status: str,
            amount: float,
            payment_schedule: list[PaymentInfo]
    ):
        """
        Создание ответа на запрос отмены заказа
        :param status: статус заказа
        :param amount: стоимость
        :param payment_schedule: график платежей, список ``podeli.model.InfoOrderResponse.PaymentInfo``
        """
        self.status = status
        self.amount = amount
        self.paymentSchedule = payment_schedule

    @classmethod
    def from_response(cls, response):
        """
        Создание ответа на запрос отмены заказа из данных ответа сервиса
        :param response: ответ сервиса
        :return: ответ ``CancelOrderResponse``
        :raises: ``podeli.error.BnlpFormatError``: не распознан ответ сервиса

        """

        try:
            return cls(
                status=response['status'],
                amount=response['amount'],
                payment_schedule=list([PaymentInfo.from_dict(x) for x in response['paymentSchedule']])
            )
        except KeyError as e:
            raise BnlpFormatError(message=e)

    def __str__(self):
        return f'Status={self.status} Amount={self.amount} payments={len(self.paymentSchedule)}'
