import json

from podeli.model.BnplOrderItem import BnplOrderItem
from podeli.model.BnplRequest import BnplRequest


class CommitOrderRequest(BnplRequest):
    """
    Запрос подтверждения заказа

    Используется для потверждения заказа
    """
    def __init__(
            self,
            order_id: int,
            x_correlation_id: str,
            amount: float,
            prepaid_amount: float,
            items: list[BnplOrderItem] = None
            ):
        """
        Создание запроса подтверждения заказа
        :param order_id: идентификатор заказа на стороне клиента
        :param x_correlation_id: идентификатор заказа на стороне сервиса, строка GUID
        :param amount: стоимость
        :param prepaid_amount: аванс
        :param items: список позиций в заказе ``podeli.model.BnplOrderItem`` или `None` если список не менялся с момента создания заказа
        """
        message = {
            "order": {
                "amount": amount,
                "prepaidAmount": prepaid_amount
            }
        }

        if items is not None and items:
            message["order"]["items"] = list([x.to_dict() for x in items])

        super(CommitOrderRequest, self).__init__(
            method="POST",
            path='/v1/orders/{0}/commit'.format(order_id),
            headers={"X-Correlation-ID": x_correlation_id},
            message=message
        )

