from podeli.error import BnlpFormatError
from podeli.model.InfoOrderResponse import PaymentInfo


class CommitOrderResponse(object):
    """
    Ответ на запрос подтвержения заказа

    Используется для получения ответа о подтвержденном заказе
    """
    def __init__(self, status: str, amount: float, payment_schedule: list = None):  # noqa: E501
        """
        Создание ответа на запрос подтверждения заказа
        :param status: статус заказа
        :param amount: стоимость в рублях
        :param payment_schedule: график платежей, список ``podeli.model.InfoOrderResponse.PaymentInfo``
        """
        self.status = status
        self.amount = amount
        self.paymentSchedule = payment_schedule

    @classmethod
    def from_response(cls, response):
        """
        Создание ответа на запрос подтверждения заказа из словая параметров
        :param response: словарь параметров
        :return: ``CommitOrderResponse``
        :raises: ``podeli.error.BnlpFormatError``: не распознан ответ сервиса
        """
        try:
            return cls(
                status=response['status'],
                amount=response['amount'],
                payment_schedule=list([PaymentInfo.from_dict(x) for x in response['paymentSchedule']])
            )
        except KeyError as e:
            raise BnlpFormatError(message=e)

    def __str__(self):
        return "status={0} amount={1} paymentScheduled={2}".format(
            self.status, self.amount, [str(x) for x in self.paymentSchedule]
        )
