import json

from podeli.model import BnplOrder
from podeli.model import BnplClientInfo
from podeli.model.BnplRequest import BnplRequest


class CreateOrderRequest(BnplRequest):
    """
    Запрос создания заказа

    Используется для создания заказа в сервисе
    """
    def __init__(
            self,
            order: BnplOrder,
            client: BnplClientInfo,
            x_correlation_id: str,
            success_url: str,
            fail_url: str,
            notification_url: str = None):
        """
        Создание запроса создания заказа
        :param order: данные о заказе ``podeli.model.BnplOrder.BnplOrder``
        :param client: данные о клиенте ``podeli.model.BnplClientInfo.BnplClientInfo``
        :param x_correlation_id: идентификатор заказа на стороне сервиса, строка GUID
        :param success_url: URL для редиректа клиента в случае успешной оплаты первого платежа по заказу
        :param fail_url:URL для редиректа клиента в случае неуспешной оплаты первого платежа по заказу
        :param notification_url: адрес для http-нотификаций, если не указан, будет использоваться по умолчанию из настроек магазина
        """
        super(CreateOrderRequest, self).__init__(
            method="POST",
            path='/v1/orders/create',
            headers={"X-Correlation-ID": x_correlation_id},
            message={
                "order": order.to_dict(),
                "clientInfo": client.to_dict(),
                "successUrl": success_url,
                "failUrl": fail_url,
                "notificationUrl": notification_url
            }
        )

